import random

class Revolver:
    def __init__(self):
        self.posicion_actual = random.randint(1, 6)
        self.posicion_bala = random.randint(1, 6)

    def disparar(self):
        disparo = False
        if self.posicion_actual == self.posicion_bala:
            disparo = True
        self.siguienteBala()
        return disparo

    def siguienteBala(self):
        if self.posicion_bala == 6:
            self.posicion_bala = 1
        else:
            self.posicion_bala = self.posicion_bala + 1

    def toString(self):
        print("Posición actual del revolver:")
        print("Posición actual: %d" % self.posicion_actual)
        print("Posición de la bala: %d" % self.posicion_bala)



from ruletarusa.Revolver import *
from ruletarusa.Jugador import *
import pickle


class Juego:
    def __init__(self, numero_jugadores):
        self.jugadores = []
        self.revolver = Revolver()

        nj = self.verificarNumeroJugadores(numero_jugadores)

        for i in range(nj):
            self.jugadores.append(Jugador(i + 1))

        inputfile = "juego.dat"
        binary_file = open(inputfile, mode='wb')
        pickle.dump(self, binary_file)

    def finJuego(self):
        fin_juego = False

        for i in range(len(self.jugadores)):
            estado_jugador = self.jugadores[i].isVivo()

            if not estado_jugador:
                fin_juego = True

        return fin_juego

    def ronda(self):
        for i in range(len(self.jugadores)):
            print("El valiente %s coge el revolver y se apunta..." % self.jugadores[i].nombre)
            self.jugadores[i].disparar(self.revolver)

            if not self.jugadores[i].vivo:
                break

    def verificarNumeroJugadores(self, numero_jugadores):
        if numero_jugadores < 1 or numero_jugadores > 6:
            numero_jugadores = 6
        return numero_jugadores




class Jugador:
    def __init__(self, id):
        self.id = id
        self.nombre = "Jugador %d" % id
        self.vivo = True

    def disparar(self, r):
        disparo = r.disparar()
        if not disparo:
            print("%s está de suerte y se ha librado... Sigue vivo." % self.nombre)
        else:
            print("Un valiente menos... %s ha muerto." % self.nombre)
            self.vivo = False

    def isVivo(self):
        return self.vivo


from setuptools import setup
 
setup(
    name='ruletarusa',
    packages=['ruletarusa'], # Mismo nombre que en la estructura de carpetas de arriba
    version='0.6',
    license='LGPL v3', # La licencia que tenga tu paquete
    description='Ruleta rusa para el proyecto de la UF4 de M06.',
    author='SLG',
    author_email='mapacheador@gmail.com',
    url='https://github.com/cfsergio/RuletaRusa', # Usa la URL del repositorio de GitHub
    download_url='https://github.com/cfsergio/RuletaRusa/archive/refs/heads/master.zip', # Te lo explico a continuación
    keywords='python ruleta rusa', # Palabras que definan tu paquete
    classifiers=['Programming Language :: Python',  # Clasificadores de compatibilidad con versiones de Python para tu paquete
                 'Programming Language :: Python :: 2.7',
                 'Programming Language :: Python :: 3.3',
                 'Programming Language :: Python :: 3.4',
                 'Programming Language :: Python :: 3.5',
                 'Programming Language :: Python :: 3.6',
                 'Programming Language :: Python :: 3.7'],
)
